ComponentAggregateBuilder class

Properties

buildExtensions Map<String, List<String>>
Mapping from input file extension to output file extensions.
no setter
config AggregatorConfig
final
hashCode int
The hash code for this object.
no setterinherited
output String
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildStep buildStep) Future<void>
Generates the outputs for a given BuildStep.
checkDependency(String package, YamlMap pubspec) bool
findDocs(BuildStep buildStep, AssetId target) Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readConfig(BuildStep buildStep, String package) Future<Reference?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited