PackageStories class

Constructors

PackageStories({required String package, required List<StoryContainer> storyContainers, required Reference? config})
const

Properties

config → Reference?
final
hashCode int
The hash code for this object.
no setterinherited
package String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storyContainers List<StoryContainer>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited