StoryContainer class

Constructors

StoryContainer({required String package, required String path, required LibraryElement library, required List<String> docs})

Properties

docs List<String>
final
hashCode int
The hash code for this object.
no setterinherited
id String
no setter
library → LibraryElement
final
package String
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited