LibraryParser class

Constructors

LibraryParser({required Resolver resolver, required bool isRootPackage, required String package, required String path, required LibraryElement library, required List<String> docs, required AggregatorConfig config, required Reference? configReference})

Properties

config AggregatorConfig
final
configReference → Reference?
final
docs List<String>
final
hashCode int
The hash code for this object.
no setterinherited
isRootPackage bool
final
library → LibraryElement
final
package String
final
path String
final
resolver → Resolver
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() Future<(String, Spec)>
buildMeta() Future<MetaDescription?>
buildStories(MetaDescription? meta) Future<List<Expression>>
checkMeta(TopLevelVariableElement element) bool
checkStory(TopLevelVariableElement element) bool
findMeta() → TopLevelVariableElement?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
withDocs(Reference meta, List<String> docs) → Expression

Operators

operator ==(Object other) bool
The equality operator.
inherited